@@ -1,46 +1,8 @@
-import os
-
-import click
 from pick import pick
 
-from ftrack_ams.functions import clearConsole, get_ftrack_session
+from ftrack_ams.fileserver import create_project_on_fileserver, get_latest_proj
+from ftrack_ams.functions import clearConsole
 from ftrack_ams.functions import create_project_name
-from . import __version__
-
-
-proj_dir = "X:/"
-projects = []
-
-
-def get_latest_proj():
-    projectcodes = []
-    for x in os.scandir(proj_dir):
-        if x.is_dir():
-            try:
-                code = int(x.name[0:4])
-            except Exception:
-                continue
-            else:
-                # print(code)
-                if code != 9999:
-                    projectcodes.append(code)
-
-    return max(projectcodes) + 1
-
-
-@click.command()
-@click.version_option(version=__version__)
-@click.option("--new", "-n", is_flag=True)
-def main(new=None):
-    session = get_ftrack_session()
-
-    print(f"👋 {session.api_user}, y'all got logged the F in")
-
-    if new:
-        create_new_project(session)
-
-
-# print(f'making a new project for {projects[p]["name"]}')
 
 
 def create_new_project(session):
@@ -232,6 +194,7 @@ def create_new_project(session):
     print(f"--- creating objects for {project_name} on ftrack")
     print(f"--- creating outlook folder for {project_name}")
     print(f"--- creating directory for {project_name} on X:/")
+    # create_project_on_fileserver(project_name)
     print(f"-- {num_int} INT tasks for {ia}") if num_int > 0 else None
     print(f"-- {num_ext} EXT tasks for {exterior_artist}") if num_ext > 0 else None
     print("--- creating photography tasks") if drone else None
@@ -239,29 +202,6 @@ def create_new_project(session):
     print(f"--- updating {project_name} on teamleader")
 
 
-def create_project_on_fileserver(project):
-    project_dir = f"X:/{project}/"
-    print(project_dir)
-    print(f"{project_dir} already exists") if os.path.isdir(
-        project_dir
-    ) else os.makedirs(project_dir)
-
-    go = os.path.join(project_dir, "GegevensOpdrachtgever")
-    print(f"{go} already exists") if os.path.isdir(go) else os.makedirs(go)
-    mv = os.path.join(project_dir, "Mails&Vergaderingen")
-    print(f"{mv} already exists") if os.path.isdir(mv) else os.makedirs(mv)
-
-    maps = os.path.join(project_dir, "Maps")
-    print(f"{maps} already exists") if os.path.isdir(maps) else os.makedirs(maps)
-
-    scenes = os.path.join(project_dir, "scenes")
-    print(f"{scenes} already exists") if os.path.isdir(scenes) else os.makedirs(scenes)
-
-
 def get_yes_no(question):
     answer = pick(["Yes", "No"], question)
     return True if answer[1] == 0 else False
-
-
-if __name__ == "__main__":
-    main()
